/*
  * Copyright 2010, David W. Drell
  *
  * This is free sample code. Use as you wish, no warranties.
  */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H
#include <QMainWindow>
#include <QGraphicsItem>
#include <QGraphicsScene>
#include <QGraphicsView>
#include <QGraphicsEllipseItem>
#include <QBrush>
#include <QScrollBar>
#include <QResizeEvent>
#include "gridlines.h"
#include "selectablelinesegmentgraphic.h"

/*! \mainpage Example Qt QGraphicsItem implemenation
 *
 * Example usage of a custom QGraphicsItem in a QGraphicsScene with examples of mouse hover events.
 *
 * My goal was to create a line segement that the user can manipulate by choosing either end
 * and draging the end. By dragging the ends, the user can position the line and set the length.
 * Also, by picking up the line at points other than the ends, the line is moved without changing size
 * or orientation.
 *
 * The mouse capture techniques were borrowed from the previous lessons on sizing a box drawing item.
 *
 */


namespace Ui
{
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

private:
    Ui::MainWindow *ui; ///< QtCreator made this instance.

    QGraphicsScene * scene ; ///< the scene will contain the graphics item 'StateBox'

    QGraphicsView * gview; ///< the graphics view will contain and display the scene.

    GridLines * gridLines; ///< this is my custom QGraphicsItem

    SelectableLineSegmentGraphic * sampleLine;


    virtual void resizeEvent(QResizeEvent *);///< re-implementing this event handler of the QMainWindow class allows my to capture re-size window values - not used in this project
};

#endif // MAINWINDOW_H
