#ifndef SELECTABLELINESEGMENTGRAPHIC_H
#define SELECTABLELINESEGMENTGRAPHIC_H

/*
  * Copyright 2010, David W. Drell
  *
  * This is free sample code. Use as you wish, no warranties.
  */

#include <QGraphicsItem>
#include <QGraphicsRectItem>
#include <QGraphicsTextItem>
#include <QGraphicsSceneHoverEvent>
#include <QGraphicsSceneMouseEvent>
#include <QColor>
#include <QPainter>
#include <QPen>
#include <QPointF>
#include "cornergrabber.h"
#include <QTransform>
#include <QGraphicsPolygonItem>
#include <QPainterPath>

/**
  * \class SelectableLineSegmentGraphic
  *
  */

class SelectableLineSegmentGraphic : public QGraphicsPolygonItem
{
public:
    SelectableLineSegmentGraphic(QPointF position);

    void setGridSpace(int space);
    void setLength(int len);


    private:


   // virtual QRectF boundingRect() const; ///< must be re-implemented in this class to provide the diminsions of the box to the QGraphicsView
    virtual void paint (QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget); ///< must be re-implemented here to pain the box on the paint-event
    virtual void hoverEnterEvent ( QGraphicsSceneHoverEvent * event ); ///< must be re-implemented to handle mouse hover enter events
    virtual void hoverLeaveEvent ( QGraphicsSceneHoverEvent * event ); ///< must be re-implemented to handle mouse hover leave events

    virtual void mouseMoveEvent ( QGraphicsSceneMouseEvent * event );///< allows the main object to be moved in the scene by capturing the mouse move events
    virtual void mousePressEvent (QGraphicsSceneMouseEvent * event );
    virtual void mouseReleaseEvent (QGraphicsSceneMouseEvent * event );

    virtual void mouseMoveEvent(QGraphicsSceneDragDropEvent *event);
    virtual void mousePressEvent(QGraphicsSceneDragDropEvent *event);
    virtual bool sceneEventFilter ( QGraphicsItem * watched, QEvent * event ) ;

    void setCornerPositions();
    void createCustomPath(QPointF mouseLocation, CornerGrabber*);
    void enclosePath(qreal lineStartX,qreal lineStartY, qreal lineEndX, qreal lineEndY  );


    QColor  _outterborderColor; ///< the hover event handlers will toggle this between red and black
    QPen    _pen; ///< the pen is used to paint the red/black border
    QPointF _location;

    QPointF _dragStart;
    int     _gridSpace;
    qreal   _lineLength;

    int _XcornerGrabBuffer;
    int _YcornerGrabBuffer;


    qreal   _graphicsItemBoundingBoxWidth;

    QPointF _lineEnd_0;
    QPointF _lineEnd_1;

    bool _cornerGrabbed;

    CornerGrabber*  _corners[2];// 0,1  - starting at x=0,y=0


    QPolygonF _selectRegion;



};


#endif // SELECTABLELINESEGMENTGRAPHIC_H
